Call Shiny to show the results of Bayesian analysis of multivariate receptor modeling in a web-based application. This object contains
plots of the posterior means and 95% posterior intervals of parameters in
an object of class bmrm.
tables of the posterior means of parameters in
an object of class bmrm.
tables of the posterior quantiles of parameters in
an object of class bmrm, for prob=(0.025, 0.05, 0.25, 0.5, 0.75, 0.95, 0.975).
tables of convergence diagnostics of parameters in
an object of class bmrm.
3-dimensional dynamic principal component plots of data (Y) and
source profiles (rows of the estimated source composition matrix P)
in an object of class bmrm. The plot can be rotated by moving the cursor.
trace plots and ACF plots of the first 6 elements of a parameter in an
object of class bmrm.
bayesMRMApp(x)shiny App
an object of class bmrm, the output of the bmrm function